@@ -525,4 +525,4 @@ main(int argc,char **argv)
 
   nco_exit_gracefully();
   return EXIT_SUCCESS;
-} /* end main() */
+} /* !main() */
